qqnorm.rma.glmm <- function(y, ...) {

   mstyle <- .get.mstyle()

   .chkclass(class(y), must="rma.glmm", notav="rma.glmm")

}
